<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Notifications</source>
        <translation>Notificações</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation><numerusform>%n segundos</numerusform><numerusform>%n segundos</numerusform></translation>
    </message>
    <message>
        <source>Number of quoted characters</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System notifications</source>
        <translation>Notificações de sistema</translation>
    </message>
    <message>
        <source>Use custom expiration timeout</source>
        <translation>Utilizar prazo de expiração padrão</translation>
    </message>
    <message>
        <source>Expiration timeout</source>
        <translation>Prazo de expiração</translation>
    </message>
    <message>
        <source>Show message content</source>
        <translation>Mostrar conteúdo da mensagem</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
</context>
</TS>